export declare const enum DeferredState {
    PENDING = 0,
    REJECTED = 1,
    RESOLVED = 2
}
/**
 * A deferred promise. This is a "controller" for a promise,
 * which lets you pass a promise around and reject or resolve
 * it from the outside.
 *
 * The actual promise is only created when the "promise"
 * property is accessed.
 */
export declare class Deferred<T> {
    /**
     * Get the current state of the promise.
     */
    get state(): DeferredState;
    /**
     * Has the promise been acquired by accessing the "promise"
     * property?
     */
    get hot(): boolean;
    /**
     * Get the underlying promise.
     * This changes the state from COLD to PENDING.
     */
    get promise(): Promise<T>;
    private _state;
    private coldReject;
    private coldResolve;
    private _promise;
    private _resolve;
    private _reject;
    constructor();
    /**
     * Resolve the promise. Throws if the promise is already resolved or rejected.
     */
    resolve(value: T | PromiseLike<T>): void;
    /**
     * Reject the promise. Throws if the promise is pending.
     */
    reject(reason: any): void;
    /**
     * Resolve the promise. Ignore if not pending.
     */
    resolvePending(val: T | PromiseLike<T>): void;
    /**
     * Reject the promise. Ignore if not pending.
     */
    rejectPending(reason: any): void;
}
