import { RpcCallShared, RpcCancelFn } from "./rpc-call-shared";
import { RpcInputStream } from "./rpc-input-stream";
import { IMessageType } from "@protobuf-ts/runtime";
import { RpcStatus } from "./rpc-status";
import { RpcMetadata } from "./rpc-metadata";
import { MethodInfo, ServiceInfo } from "./reflection-info";
/**
 * A client streaming RPC call. This means that the clients sends 0, 1, or
 * more messages to the server, and the server replies with exactly one
 * message.
 */
export declare class ClientStreamingCall<I extends object = object, O extends object = object> implements RpcCallShared<I, O> {
    /**
     * Reflection information about the service this call belongs to.
     */
    readonly serviceInfo: ServiceInfo;
    /**
     * Reflection information about this call.
     */
    readonly methodInfo: MethodInfo<I, O>;
    /**
     * The input type of the RPC.
     */
    readonly requestType: IMessageType<I>;
    /**
     * Request headers being sent with the request.
     *
     * Request headers are provided in the `meta` property of the
     * `RpcOptions` passed to a call.
     */
    readonly requestHeaders: Readonly<RpcMetadata>;
    /**
     * Request messages from the client.
     */
    readonly requestStream: RpcInputStream<I>;
    /**
     * The output type of the RPC.
     */
    readonly responseType: IMessageType<O>;
    /**
     * The response headers that the server sent.
     *
     * This promise will reject with a `RpcError` when the server sends a
     * error status code.
     */
    readonly responseHeaders: Promise<RpcMetadata>;
    /**
     * The message the server replied with.
     */
    readonly responseMessage: Promise<O>;
    /**
     * The response status the server replied with.
     *
     * This promise will resolve when the server has finished the request
     * successfully.
     *
     * If the server replies with an error status, this promise will
     * reject with a `RpcError`.
     */
    readonly responseStatus: Promise<RpcStatus>;
    /**
     * The trailers the server attached to the response.
     *
     * This promise will resolve when the server has finished the request
     * successfully.
     *
     * If the server replies with an error status, this promise will
     * reject with a `RpcError`.
     */
    readonly responseTrailers: Promise<RpcMetadata>;
    private readonly cancelFn;
    constructor(serviceInfo: ServiceInfo, methodInfo: MethodInfo<I, O>, requestType: IMessageType<I>, requestHeaders: Readonly<RpcMetadata>, requestStream: RpcInputStream<I>, responseType: IMessageType<O>, responseHeaders: Promise<RpcMetadata>, responseMessage: Promise<O>, responseStatus: Promise<RpcStatus>, responseTrailers: Promise<RpcMetadata>, cancelFn: RpcCancelFn);
    /**
     * Cancel this call.
     */
    cancel(): void;
}
